==> digium_phones-2.10.0.8.tgz: digium_phones/views/digium_phones_networks.php <==
<h2>Networks</h2>
<hr />

<form name="digium_phones_networks" method="post" action="config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit">
<script>
$().ready(function() {
<?php
$networks = $digium_phones->get_networks();

if (isset($_GET['network']) and !isset($_GET['deletenetwork_submit'])) {
	$editnetwork = $_GET['network'];
}

if ($editnetwork != null) {
	if ($editnetwork == 0) {
?>
		$('#networkname').val("New Network");
<?php
	} else {
?>
		$('#networkname').val($('#network<?php echo $editnetwork?>name').text());
<?php
	}
?>
	$('#network').val(<?php echo $editnetwork?>);

	$('div[id=editingnetwork]').show();
<?php
}

foreach ($networks as $networkid=>$network) {
	if ($editnetwork == $networkid) {
		foreach ($network['settings'] as $key=>$val) {
?>
			if ($('#<?php echo $key?>') != null) {
				$('#<?php echo $key?>').val('<?php echo $val?>');
			}
<?php
		}
	}
}
?>
});
$('form').submit(function() {
	if ($.trim($('#networkname').val()).length <= 0) {
		alert('Network Name cannot be blank.');
		return false;
	}
	if ($.trim($('#cidr').val()).length <= 0) {
		alert('CIDR cannot be blank.');
		return false;
	}
});
</script>
<input type="button" value="Add network" onclick="location.href='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit&network=0'" />
<p>

<table style="border-collapse:collapse; border-style:outset; border-width: 1px; ">
<tr>
<th style="border-style:inset; border-width:1px; "><a href="#" class="info">Network Name<span>A Network's named identifier.  This will be present in the phone's preferences menu and is used to manually select a network from the phone, if required.
</span></a></th>
<th style="border-style:inset; border-width:1px; width:75px; "><a href="#" class="info">CIDR<span>A Network's address, represented using CIDR notation.  For more information about CIDR notation, please see http://en.wikipedia.org/wiki/CIDR_notation.  If the phone, when it boots, discovers that its IP address matches the CIDR of an Network it has been assigned, then it will use those Network settings for accessing the PBX.
</span></a></th>
<th style="border-style:inset; border-width:1px; "><a href="#" class="info">Actions<span>"Edit" provides additional editing control over a selected network. "Delete" removes the specified network.</span></a></th>
</tr>
<?php
foreach ($networks as $networkid=>$network) {
?>
<tr>
<td valign="top" style="width: 200px; border-style:inset; border-width: 1px; ">
	<span id="network<?php echo $networkid?>name"><?php echo $network['name']?></span>
</td>
<td valign="top" style="border-style:inset; border-width:1px; ">
	<?php echo $network['settings']['cidr']?>
</td>
<td valign="top" style="border-style:inset; border-width:1px; white-space: nowrap; ">
	<input type="button" value="Edit" onClick="parent.location='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit&network=<?php echo $networkid?>'">
<?php
	if ($networkid != -1) {
?>
	<input type="button" value="Delete" onClick="parent.location='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit&deletenetwork_submit=Delete&network=<?php echo $networkid?>'">
<?php
	}
?>
</td>
</tr>
<?php
}
?>
</table>

<hr />

<div id="editingnetwork" style="display: none;">
	<input type="hidden" id="network" name="network" />
	<div class="setting">
		<label for="networkname"><a href="#" class="info">Network Name:<span>Sets an identifier for the network.  This will be present in the phone's preferences menu and is used to manually select a network from the phone, if required.</span></a></label>
		<input type="text" id="networkname" name="networkname" <?php echo $editnetwork == -1 ? "readonly" : ""?> style="width: 200px; "/>
	</div>

	<div>
		<label for="cidr"><a href="#" class="info">Network CIDR:<span>Defines a network address, represented using CIDR notation.  For more information about CIDR notation, please see http://en.wikipedia.org/wiki/CIDR_notation.  If the phone, when it boots, discovers that its IP address matches the CIDR of an Network it has been assigned, then it will use those Network settings for accessing the PBX.</span></a></label>
		<input type="text" id="cidr" name="cidr" <?php echo $editnetwork == -1 ? "readonly" : ""?> style="width: 200px; "/>
	</div>

	<div>
		<label for="registration_address"><a href="#" class="info">Registration Address:<span>Sets the SIP hostname or IP address used by the phone to access the PBX.</span></a></label>
		<input type="text" id="registration_address" name="registration_address" style="width: 200px; "/>
	</div>

	<div>
		<label for="registration_port"><a href="#" class="info">Registration Port:<span>Sets the port used by the phone to access the PBX.</span></a></label>
		<input type="text" id="registration_port" name="registration_port" style="width: 200px; "/>
	</div>

	<div onclick="$('#divadvanced').slideToggle('fast');" style="cursor: pointer; background-color: #CCC; margin: 3px; padding: 2px; border-style:solid; border-width: 1px; ">
	<a href="javascript:void(null);">Advanced Options:</a>
	</div>
	<div id="divadvanced" style="display: none; margin: 3px; padding: 2px; border-style:solid; border-width: 1px; ">
		<div>
			<label for="file_url_prefix"><a href="#" class="info">File URL Prefix:<span>Defines the URL prefix used by the phone to retrieve firmware and ringtones.</span></a></label>
			<input type="text" id="file_url_prefix" name="file_url_prefix" style="width: 200px; "/>
		</div>

		<br />

		<div>
			<label for="alternate_registration_address"><a href="#" class="info">Alternate Registration Address:<span>Optional.  Sets an alternate host to which the phone will register itself simultaneously.  DPMA Application function is not maintained with the alternate host, but basic call functionality is maintained.</span></a></label>
			<input type="text" id="alternate_registration_address" name="alternate_registration_address" style="width: 200px; "/>
		</div>

		<div>
			<label for="alternate_registration_port"><a href="#" class="info">Alternate Registration Port:<span>Optional. Sets the port for the Alternate Registration Address.</span></a></label>
			<input type="text" id="alternate_registration_port" name="alternate_registration_port" style="width: 200px; "/>
		</div>

		<br />

		<div>
			<label for="ntp_server"><a href="#" class="info">NTP Server:<span>Defines the NTP server the phone will synchronize to in order to maintain its time.</span></a></label>
			<input type="text" id="ntp_server" name="ntp_server" style="width: 200px; "/>
		</div>

		<div>
			<label for="syslog_level"><a href="#" class="info">Syslog Level:<span>If enabled, sets a logging level used by the phone to output syslog messages.</span></a></label>
			<select id="syslog_level" name="syslog_level">
				<option value="" selected>Disabled (Default)</option>
				<option value="debug">Debug</option>
				<option value="error">Error</option>
				<option value="warn">Warning</option>
				<option value="info">Info</option>
			</select>
		</div>

		<div>
			<label for="syslog_server"><a href="#" class="info">Syslog Server:<span>If Syslog is enabled, sets the server to which syslog messages are sent by the phone.</span></a></label>
			<input type="text" id="syslog_server" name="syslog_server" style="width: 200px; "/>
		</div>

		<div>
			<label for="syslog_port"><a href="#" class="info">Syslog Port:<span>If Syslog is enabled, sets the port to which syslog messages are sent by the phone.</span></a></label>
			<input type="text" id="syslog_port" name="syslog_port" style="width: 200px; "/>
		</div>

		<br />

		<div>
			<label for="network_vlan_discovery_mode"><a href="#" class="info">VLAN Discovery:<span>Digium phones default to VLAN discovery using LLDP.  If LLDP is not available on your switch, you may elect for Manual VLAN configuration, or VLANs may be disabled.</span></a></label>
			<select id="network_vlan_discovery_mode" name="network_vlan_discovery_mode">
				<option value="" selected>LLDP (Default)</option>
				<option value="none">None</option>
				<option value="manual">Manual</option>
			</select>
		</div>

		<div>
			<label for="network_vlan_id"><a href="#" class="info">VLAN ID:<span>If a Digium phone is configured for manual VLAN Discovery, sets the VLAN ID to which the phone will bind.</span></a></label>
			<input type="text" id="network_vlan_id" name="network_vlan_id" style="width: 200px; "/>
		</div>

		<div>
			<label for="network_vlan_qos"><a href="#" class="info">VLAN QoS:<span>If a Digium phone is configured for manual VLAN Discovery, sets the VLAN QoS to which the phone will bind.</span></a></label>
			<input type="text" id="network_vlan_qos" name="network_vlan_qos" style="width: 200px; "/>
		</div>

		<div>
			<label for="sip_dscp"><a href="#" class="info">Signalling DSCP:<span>Specifies the DSCP field of the DiffServ byte for SIP Signaling QoS, defaults to 24.</span></a></label>
			<input type="text" id="sip_dscp" name="sip_dscp" style="width: 200px; "/>
		</div>

		<div>
			<label for="rtp_dscp"><a href="#" class="info">Media DSCP:<span>Specifies the DSCP field of the DiffServ byte for RTP Media QoS, defaults to 24.</span></a></label>
			<input type="text" id="rtp_dscp" name="rtp_dscp" style="width: 200px; "/>
		</div>
	</div>

	<br />

	<input type="button" value="Cancel" onclick="location.href='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit'"/>
	<input type="submit" name="editnetwork_submit" value="Save"/>
</div>
</form>

==> digium_phones-2.10.0.9.tgz: digium_phones/views/digium_phones_networks.php <==
<h2>Networks</h2>
<hr />

<form name="digium_phones_networks" method="post" action="config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit">
<script>
$().ready(function() {
<?php
$networks = $digium_phones->get_networks();

if (isset($_GET['network']) and !isset($_GET['deletenetwork_submit'])) {
	$editnetwork = $_GET['network'];
}

if ($editnetwork != null) {
	if ($editnetwork == 0) {
?>
		$('#networkname').val("New Network");
<?php
	} else {
?>
		$('#networkname').val($('#network<?php echo $editnetwork?>name').text());
<?php
	}
?>
	$('#network').val(<?php echo $editnetwork?>);

	$('div[id=editingnetwork]').show();
<?php
}

foreach ($networks as $networkid=>$network) {
	if ($editnetwork == $networkid) {
		foreach ($network['settings'] as $key=>$val) {
?>
			if ($('#<?php echo $key?>') != null) {
				$('#<?php echo $key?>').val('<?php echo $val?>');
			}
<?php
		}
	}
}
?>
});
$('form').submit(function() {
	if ($.trim($('#networkname').val()).length <= 0) {
		alert('Network Name cannot be blank.');
		return false;
	}
	if ($.trim($('#cidr').val()).length <= 0) {
		alert('CIDR cannot be blank.');
		return false;
	}
});
</script>
<input type="button" value="Add network" onclick="location.href='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit&network=0'" />
<p>

<table style="border-collapse:collapse; border-style:outset; border-width: 1px; ">
<tr>
<th style="border-style:inset; border-width:1px; "><a href="#" class="info">Network Name<span>A Network's named identifier.  This will be present in the phone's preferences menu and is used to manually select a network from the phone, if required.
</span></a></th>
<th style="border-style:inset; border-width:1px; width:75px; "><a href="#" class="info">CIDR<span>A Network's address, represented using CIDR notation.  For more information about CIDR notation, please see http://en.wikipedia.org/wiki/CIDR_notation.  If the phone, when it boots, discovers that its IP address matches the CIDR of an Network it has been assigned, then it will use those Network settings for accessing the PBX.
</span></a></th>
<th style="border-style:inset; border-width:1px; "><a href="#" class="info">Actions<span>"Edit" provides additional editing control over a selected network. "Delete" removes the specified network.</span></a></th>
</tr>
<?php
foreach ($networks as $networkid=>$network) {
?>
<tr>
<td valign="top" style="width: 200px; border-style:inset; border-width: 1px; ">
	<span id="network<?php echo $networkid?>name"><?php echo $network['name']?></span>
</td>
<td valign="top" style="border-style:inset; border-width:1px; ">
	<?php echo $network['settings']['cidr']?>
</td>
<td valign="top" style="border-style:inset; border-width:1px; white-space: nowrap; ">
	<input type="button" value="Edit" onClick="parent.location='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit&network=<?php echo $networkid?>'">
<?php
	if ($networkid != -1) {
?>
	<input type="button" value="Delete" onClick="parent.location='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit&deletenetwork_submit=Delete&network=<?php echo $networkid?>'">
<?php
	}
?>
</td>
</tr>
<?php
}
?>
</table>

<hr />

<div id="editingnetwork" style="display: none;">
	<input type="hidden" id="network" name="network" />
	<div class="setting">
		<label for="networkname"><a href="#" class="info">Network Name:<span>Sets an identifier for the network.  This will be present in the phone's preferences menu and is used to manually select a network from the phone, if required.</span></a></label>
		<input type="text" id="networkname" name="networkname" <?php echo $editnetwork == -1 ? "readonly" : ""?> style="width: 200px; "/>
	</div>

	<div>
		<label for="cidr"><a href="#" class="info">Network CIDR:<span>Defines a network address, represented using CIDR notation.  For more information about CIDR notation, please see http://en.wikipedia.org/wiki/CIDR_notation.  If the phone, when it boots, discovers that its IP address matches the CIDR of an Network it has been assigned, then it will use those Network settings for accessing the PBX.</span></a></label>
		<input type="text" id="cidr" name="cidr" <?php echo $editnetwork == -1 ? "readonly" : ""?> style="width: 200px; "/>
	</div>

	<div>
		<label for="registration_address"><a href="#" class="info">Registration Address:<span>Sets the SIP hostname or IP address used by the phone to access the PBX.</span></a></label>
		<input type="text" id="registration_address" name="registration_address" style="width: 200px; "/>
	</div>

	<div>
		<label for="registration_port"><a href="#" class="info">Registration Port:<span>Sets the port used by the phone to access the PBX.</span></a></label>
		<input type="text" id="registration_port" name="registration_port" style="width: 200px; "/>
	</div>

	<div onclick="$('#divadvanced').slideToggle('fast');" style="cursor: pointer; background-color: #CCC; margin: 3px; padding: 2px; border-style:solid; border-width: 1px; ">
	<a href="javascript:void(null);">Advanced Options:</a>
	</div>
	<div id="divadvanced" style="display: none; margin: 3px; padding: 2px; border-style:solid; border-width: 1px; ">
		<div>
			<label for="file_url_prefix"><a href="#" class="info">File URL Prefix:<span>Defines the URL prefix used by the phone to retrieve firmware and ringtones.</span></a></label>
			<input type="text" id="file_url_prefix" name="file_url_prefix" style="width: 200px; "/>
		</div>

		<br />

		<div>
			<label for="alternate_registration_address"><a href="#" class="info">Alternate Registration Address:<span>Optional.  Sets an alternate host to which the phone will register itself simultaneously.  DPMA Application function is not maintained with the alternate host, but basic call functionality is maintained.</span></a></label>
			<input type="text" id="alternate_registration_address" name="alternate_registration_address" style="width: 200px; "/>
		</div>

		<div>
			<label for="alternate_registration_port"><a href="#" class="info">Alternate Registration Port:<span>Optional. Sets the port for the Alternate Registration Address.</span></a></label>
			<input type="text" id="alternate_registration_port" name="alternate_registration_port" style="width: 200px; "/>
		</div>

		<br />

		<div>
			<label for="ntp_server"><a href="#" class="info">NTP Server:<span>Defines the NTP server the phone will synchronize to in order to maintain its time.</span></a></label>
			<input type="text" id="ntp_server" name="ntp_server" style="width: 200px; "/>
		</div>

		<div>
			<label for="syslog_level"><a href="#" class="info">Syslog Level:<span>If enabled, sets a logging level used by the phone to output syslog messages.</span></a></label>
			<select id="syslog_level" name="syslog_level">
				<option value="" selected>Disabled (Default)</option>
				<option value="debug">Debug</option>
				<option value="error">Error</option>
				<option value="warn">Warning</option>
				<option value="info">Info</option>
			</select>
		</div>

		<div>
			<label for="syslog_server"><a href="#" class="info">Syslog Server:<span>If Syslog is enabled, sets the server to which syslog messages are sent by the phone.</span></a></label>
			<input type="text" id="syslog_server" name="syslog_server" style="width: 200px; "/>
		</div>

		<div>
			<label for="syslog_port"><a href="#" class="info">Syslog Port:<span>If Syslog is enabled, sets the port to which syslog messages are sent by the phone.</span></a></label>
			<input type="text" id="syslog_port" name="syslog_port" style="width: 200px; "/>
		</div>

		<br />

		<div>
			<label for="network_vlan_discovery_mode"><a href="#" class="info">Network VLAN Discovery:<span>Digium phones default to VLAN discovery using LLDP.  If LLDP is not available on your switch, you may elect for Manual VLAN configuration, or VLANs may be disabled.</span></a></label>
			<select id="network_vlan_discovery_mode" name="network_vlan_discovery_mode">
				<option value="LLDP" selected>LLDP (Default)</option>
				<option value="NONE">None</option>
				<option value="MANUAL">Manual</option>
			</select>
		</div>

		<div>
			<label for="network_vlan_id"><a href="#" class="info">Network VLAN ID:<span>If a Digium phone is configured for manual VLAN Discovery, sets the VLAN ID to which the phone will bind.</span></a></label>
			<input type="text" id="network_vlan_id" name="network_vlan_id" style="width: 200px; "/>
		</div>

		<div>
			<label for="network_vlan_qos"><a href="#" class="info">Network VLAN QoS:<span>If a Digium phone is configured for manual VLAN Discovery, sets the VLAN QoS to which the phone will bind.</span></a></label>
			<input type="text" id="network_vlan_qos" name="network_vlan_qos" style="width: 200px; "/>
		</div>

		<div>
			<label for="pc_vlan_id"><a href="#" class="info">PC VLAN ID:<span>Sets the VLAN ID to which the phone will bind, for the PC port.</span></a></label>
			<input type="text" id="pc_vlan_id" name="pc_vlan_id" style="width: 200px; "/>
		</div>

		<div>
			<label for="pc_vlan_qos"><a href="#" class="info">PC VLAN QoS:<span>If a Digium phone is configured for manual VLAN Discovery, sets the VLAN QoS to which the phone will bind, for the PC port.</span></a></label>
			<input type="text" id="pc_vlan_qos" name="pc_vlan_qos" style="width: 200px; "/>
		</div>

		<div>
			<label for="sip_dscp"><a href="#" class="info">Signalling DSCP:<span>Specifies the DSCP field of the DiffServ byte for SIP Signaling QoS, defaults to 24.</span></a></label>
			<input type="text" id="sip_dscp" name="sip_dscp" style="width: 200px; "/>
		</div>

		<div>
			<label for="rtp_dscp"><a href="#" class="info">Media DSCP:<span>Specifies the DSCP field of the DiffServ byte for RTP Media QoS, defaults to 24.</span></a></label>
			<input type="text" id="rtp_dscp" name="rtp_dscp" style="width: 200px; "/>
		</div>
	</div>

	<br />

	<input type="button" value="Cancel" onclick="location.href='config.php?type=setup&display=digium_phones&digium_phones_form=networks_edit'"/>
	<input type="submit" name="editnetwork_submit" value="Save"/>
</div>
</form>
